; ##############################################################################
; ##############################################################################
; ##############################################################################
; 1-Wire, Reset und Presence-Test												
ONE_WIRE_RESET_PRESENCE:

	; Port auf Ausgang + LOW		
	cbi PORTC,0		; LOW-PEGEL		
	sbi DDRC,0		; AUF AUSGANG	
	; RESET IMPULS ca. 500 s		
	rcall wait_500us
	; Port auf EINGANG + HIGH		
	sbi PORTC,0		; HIGH-PEGEL 	
	sbi DDRC,0		; AUF AUSGANG	
	; Pause 
	rcall wait_100us
	; MASTER SAMPLES			
	in temp,PINC
	; PIN selektieren			
	andi temp,0b00000001
	tst temp
	brne ONE_WIRE_RESET_PRESENCE_ERROR
	rjmp ONE_WIRE_RESET_PRESENCE_OK
;-------------------------------------------------------------------------------
ONE_WIRE_RESET_PRESENCE_OK:
	cbi PORTD,LED_D_GRUEN	; GRN	an
	rcall wait_1ms
	ret
;-------------------------------------------------------------------------------
ONE_WIRE_RESET_PRESENCE_ERROR:
	cbi PORTD,LED_D_ROT		; ROT	
	sbi PORTD,LED_D_GRUEN	; GRN	aus
	rcall wait_1ms

ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; 1 DATENBYTE 1-wire schreiben													
;																				
; inp: temp1																	
;																				
; rcall DS_DATA_WRITE		; inp: temp1										
;																				
ONE_WIRE_DATA_WRITE:

	LSR temp1						; 1x rechts 1 rollt raus (LSB)
	rcall ONE_WIRE_DATA_WRITE_BIT	; BIT-0 schreiben			
	LSR temp1						; 1x rechts 1 rollt raus 	
	rcall ONE_WIRE_DATA_WRITE_BIT	; BIT-1 schreiben			
	LSR temp1						; 1x rechts 1 rollt raus 	
	rcall ONE_WIRE_DATA_WRITE_BIT	; BIT-2 schreiben			
	LSR temp1						; 1x rechts 1 rollt raus 	
	rcall ONE_WIRE_DATA_WRITE_BIT	; BIT-3 schreiben			
	LSR temp1						; 1x rechts 1 rollt raus 	
	rcall ONE_WIRE_DATA_WRITE_BIT	; BIT-4 schreiben			
	LSR temp1						; 1x rechts 1 rollt raus 	
	rcall ONE_WIRE_DATA_WRITE_BIT	; BIT-5 schreiben			
	LSR temp1						; 1x rechts 1 rollt raus 	
	rcall ONE_WIRE_DATA_WRITE_BIT	; BIT-6 schreiben			
	LSR temp1						; 1x rechts 1 rollt raus (MSB)
	rcall ONE_WIRE_DATA_WRITE_BIT	; BIT-7 schreiben			
	; kurze Pause
	rcall wait_100us
ret
;-------------------------------------------------------------------------------
ONE_WIRE_DATA_WRITE_BIT:
	; CARRY auswerten	
	brcs ONE_WIRE_DATA_WRITE_BIT_HIGH		; wenn CARRY=1 dann HIGH	
	rjmp ONE_WIRE_DATA_WRITE_BIT_LOW		; wenn CARRY=0 dann LOW 	
;-------------------------------------------------------------------------------
ONE_WIRE_DATA_WRITE_BIT_LOW:
	; "0" SLOT 60...120s (LOW-PEGEL)							
	cbi PORTC,0		; LOW-PEGEL				
	sbi DDRC,0		; AUF AUSGANG			
	rcall wait_100us; 100s PAUSE = "0" SLOT	
	sbi PORTC,0		; HIGH-PEGEL			
	cbi DDRC,0		; AUF EINGANG			
ret
;-------------------------------------------------------------------------------
ONE_WIRE_DATA_WRITE_BIT_HIGH:
	; "1" SLOT 1...15s LOW_PEGEL, dann mind. 45s HIGH-PEGEL	
	cbi PORTC,0		; LOW-PEGEL				
	sbi DDRC,0		; AUF AUSGANG			
	nop				;  5s PAUSE = "1" SLOT	
	nop
	nop
	nop
	nop
	sbi PORTC,0		; HIGH-PEGEL			
	cbi DDRC,0		; AUF EINGANG			
	rcall wait_100us; 100s PAUSE = "1" SLOT	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; 1 DATENBYTE 1-wire lesen														
;																				
; out: temp1																	
;																				
; rcall DS_DATA_READ		; OUT: temp1										
;																				
ONE_WIRE_DATA_READ:
	clr temp1

	rcall ONE_WIRE_DATA_READ_BIT	; LSB
	rcall ONE_WIRE_DATA_READ_BIT
	rcall ONE_WIRE_DATA_READ_BIT
	rcall ONE_WIRE_DATA_READ_BIT
	rcall ONE_WIRE_DATA_READ_BIT
	rcall ONE_WIRE_DATA_READ_BIT
	rcall ONE_WIRE_DATA_READ_BIT
	rcall ONE_WIRE_DATA_READ_BIT	; MSB
	ret
;-------------------------------------------------------------------------------
; ein BIT vom SLAVE einlesen													
ONE_WIRE_DATA_READ_BIT:
	; kurzer LOW-IMPULS 1...5s
	cbi PORTC,0		; LOW-PEGEL				
	sbi DDRC,0		; AUF AUSGANG			
	nop
	sbi PORTC,0		; HIGH-PEGEL			
	cbi DDRC,0		; AUF EINGANG			
	; ca 10s warten			
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	cbi PORTD,LED_D_GELB	; GELB 		
	; MASTER SAMPLES			
	in temp,PINC
	sbi PORTD,LED_D_GELB	; GELB 		
	; PIN selektieren			
	andi temp,0b00000001
	tst temp
	brne ONE_WIRE_DATA_READ_1_SLOT
	rjmp ONE_WIRE_DATA_READ_0_SLOT
;-------------------------------------------------------------------------------
ONE_WIRE_DATA_READ_0_SLOT:
	; 1x rechts 
	LSR temp1
	; warten
	rcall wait_50us
	ret
ONE_WIRE_DATA_READ_1_SLOT:
	SEC
	ROR temp1
	; warten
	rcall wait_50us
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################

